@@ -29,12 +29,13 @@
  * 
  * Creates a new #PangoItem structure initialized to default values.
  * 
- * Return value: the new #PangoItem
+ * Return value: the newly allocated #PangoItem, which should
+ *               be freed with pango_item_free().
  **/
 PangoItem *
 pango_item_new (void)
 {
-  PangoItem *result = g_new0 (PangoItem, 1);
+  PangoItem *result = g_slice_new0 (PangoItem);
 
   return result;
 }
@@ -45,13 +46,14 @@ pango_item_new (void)
  * 
  * Copy an existing #PangoItem structure.
  * 
- * Return value: the new #PangoItem
+ * Return value: the newly allocated #PangoItem, which should
+ *               be freed with pango_item_free().
  **/
 PangoItem *
 pango_item_copy (PangoItem *item)
 {
   GSList *extra_attrs, *tmp_list;
-  PangoItem *result = g_new (PangoItem, 1);
+  PangoItem *result = g_slice_new (PangoItem);
 
   result->offset = item->offset;
   result->length = item->length;
@@ -92,7 +94,7 @@ pango_item_free (PangoItem *item)
   if (item->analysis.font)
     g_object_unref (item->analysis.font);
 
-  g_free (item);
+  g_slice_free (PangoItem, item);
 }
 
 GType
@@ -124,7 +126,8 @@ pango_item_get_type (void)
  * item isn't available, so pango_item_split() can't count the char
  * length of the split items itself.
  * 
- * Return value: new item representing text before @split_index
+ * Return value: new item representing text before @split_index, which
+ *               should be freed with pango_item_free().
  **/
 PangoItem*
 pango_item_split (PangoItem  *orig,
